@@ -9,7 +9,6 @@ import io
 import itertools
 import os
 import pickle
-import re
 import select
 import shutil
 import subprocess
@@ -25,10 +24,12 @@ import cloudpickle
 def environment_variables(**kwargs: str) -> Iterator[None]:
     backup = {x: os.environ[x] for x in kwargs if x in os.environ}
     os.environ.update(kwargs)
-    yield
-    for x in kwargs:
-        del os.environ[x]
-    os.environ.update(backup)
+    try:
+        yield
+    finally:
+        for x in kwargs:
+            del os.environ[x]
+        os.environ.update(backup)
 
 
 class UncompletedJobError(RuntimeError):
@@ -59,6 +60,9 @@ class JobPaths:
 
     @property
     def submission_file(self) -> Path:
+        if self.job_id and "_" in self.job_id:
+            # We only have one submission file per job array
+            return self._format_id(self.folder / "%A_submission.sh")
         return self._format_id(self.folder / "%j_submission.sh")
 
     @property
@@ -81,7 +85,13 @@ class JobPaths:
         """Replace id tag by actual id if available"""
         if self.job_id is None:
             return Path(path)
-        return Path(str(path).replace("%j", str(self.job_id)).replace("%t", str(self.task_id)))
+        replaced_path = str(path).replace("%j", str(self.job_id)).replace("%t", str(self.task_id))
+        array_id, *array_index = str(self.job_id).split("_", 1)
+        if "%a" in replaced_path:
+            if len(array_index) != 1:
+                raise ValueError("%a is in the folder path but this is not a job array")
+            replaced_path = replaced_path.replace("%a", array_index[0])
+        return Path(replaced_path.replace("%A", array_id))
 
     def move_temporary_file(self, tmp_path: Union[Path, str], name: str) -> None:
         self.folder.mkdir(parents=True, exist_ok=True)
@@ -91,7 +101,8 @@ class JobPaths:
     def get_first_id_independent_folder(folder: Union[Path, str]) -> Path:
         """Returns the closest folder which is id independent"""
         parts = Path(folder).expanduser().absolute().parts
-        indep_parts = itertools.takewhile(lambda x: not any(tag in x for tag in ["%j", "%t"]), parts)
+        tags = ["%j", "%t", "%A", "%a"]
+        indep_parts = itertools.takewhile(lambda x: not any(tag in x for tag in tags), parts)
         return Path(*indep_parts)
 
     def __repr__(self) -> str:
@@ -209,18 +220,6 @@ def copy_par_file(par_file: Union[str, Path], folder: Union[str, Path]) -> Path:
     return dst_name
 
 
-def sanitize(s: str, only_alphanum: bool = True, in_quotes: bool = True) -> str:
-    """Sanitize the string"""
-    if only_alphanum:
-        # Replace all consecutive non-alphanum character by _
-        return re.sub(r"[\W_]+", "_", s)
-    if in_quotes:
-        # Escape double quotes in the original string and put it between double quotes
-        s = s.replace('"', '\\"')
-        s = f'"{s}"'
-    return s
-
-
 def pickle_load(filename: Union[str, Path]) -> Any:
     # this is used by cloudpickle as well
     with open(filename, "rb") as ifile:
@@ -260,7 +259,7 @@ def copy_process_streams(
         ready, _, _ = select.select(fds, [], [])
         for fd in ready:
             p_stream, string, std = stream_by_fd[fd]
-            raw_buf = p_stream.read(2 ** 16)
+            raw_buf = p_stream.read(2**16)
             if not raw_buf:
                 fds.remove(fd)
                 continue
